==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor.md <==
# AwsIoTThingVibrationSensor


```text
aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor
```

```text
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')
```



| Illustration | AwsIoTThingVibrationSensor | AwsIoTThingVibrationSensorCard | AwsIoTThingVibrationSensorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor.png) | ![illustration for AwsIoTThingVibrationSensor](../../../aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor.Local.png) | ![illustration for AwsIoTThingVibrationSensorCard](../../../aws-20210730/Resource/LoT/AwsIoTThingVibrationSensorCard.Local.png) | ![illustration for AwsIoTThingVibrationSensorGroup](../../../aws-20210730/Resource/LoT/AwsIoTThingVibrationSensorGroup.Local.png) |




## AwsIoTThingVibrationSensor

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingVibrationSensor
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')

' renders the element
AwsIoTThingVibrationSensor('AwsIoTThingVibrationSensor', 'Aws Io T Thing Vibration Sensor', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingVibrationSensor
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')

' renders the element
AwsIoTThingVibrationSensor('AwsIoTThingVibrationSensor', 'Aws Io T Thing Vibration Sensor', 'an optional tech label')
@enduml
```

## AwsIoTThingVibrationSensorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingVibrationSensorCard
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')

' renders the element
AwsIoTThingVibrationSensorCard('AwsIoTThingVibrationSensorCard', 'Aws Io T Thing Vibration Sensor Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingVibrationSensorCard
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')

' renders the element
AwsIoTThingVibrationSensorCard('AwsIoTThingVibrationSensorCard', 'Aws Io T Thing Vibration Sensor Card', 'an optional description')
@enduml
```

## AwsIoTThingVibrationSensorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingVibrationSensorGroup
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')

' renders the element
AwsIoTThingVibrationSensorGroup('AwsIoTThingVibrationSensorGroup', 'Aws Io T Thing Vibration Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingVibrationSensorGroup
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')

' renders the element
AwsIoTThingVibrationSensorGroup('AwsIoTThingVibrationSensorGroup', 'Aws Io T Thing Vibration Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor.md <==
# AwsIoTThingVibrationSensor


```text
aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor
```

```text
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')
```



| Illustration | AwsIoTThingVibrationSensor | AwsIoTThingVibrationSensorCard | AwsIoTThingVibrationSensorGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor.png) | ![illustration for AwsIoTThingVibrationSensor](../../../aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor.Local.png) | ![illustration for AwsIoTThingVibrationSensorCard](../../../aws-20210730/Resource/LoT/AwsIoTThingVibrationSensorCard.Local.png) | ![illustration for AwsIoTThingVibrationSensorGroup](../../../aws-20210730/Resource/LoT/AwsIoTThingVibrationSensorGroup.Local.png) |




## AwsIoTThingVibrationSensor

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingVibrationSensor
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')

' renders the element
AwsIoTThingVibrationSensor('AwsIoTThingVibrationSensor', 'Aws Io T Thing Vibration Sensor', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingVibrationSensor
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')

' renders the element
AwsIoTThingVibrationSensor('AwsIoTThingVibrationSensor', 'Aws Io T Thing Vibration Sensor', 'an optional tech label')
@enduml
```

## AwsIoTThingVibrationSensorCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingVibrationSensorCard
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')

' renders the element
AwsIoTThingVibrationSensorCard('AwsIoTThingVibrationSensorCard', 'Aws Io T Thing Vibration Sensor Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingVibrationSensorCard
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')

' renders the element
AwsIoTThingVibrationSensorCard('AwsIoTThingVibrationSensorCard', 'Aws Io T Thing Vibration Sensor Card', 'an optional description')
@enduml
```

## AwsIoTThingVibrationSensorGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingVibrationSensorGroup
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')

' renders the element
AwsIoTThingVibrationSensorGroup('AwsIoTThingVibrationSensorGroup', 'Aws Io T Thing Vibration Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTThingVibrationSensorGroup
include('aws-20210730/Resource/LoT/AwsIoTThingVibrationSensor')

' renders the element
AwsIoTThingVibrationSensorGroup('AwsIoTThingVibrationSensorGroup', 'Aws Io T Thing Vibration Sensor Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
